#coding=utf-8
import sys
defaultencoding = 'utf-8'
from setuptools import setup,find_packages

setup(
    name="baizhanSuperMath7",
    version="1.0",
    description="这是第一个对外发布的模块",
    author="宋海兵",
    author_email="2403181713@qq.com",
    package=["baizhanSuperMath7.demo1","baizhanSuperMath7.demo2"]
    )
